@@ -1,6 +1,4 @@
 package Kwiki::SOAP::Fortune;
-use strict;
-use warnings;
 use Kwiki::SOAP '-Base';
 use mixin 'Kwiki::Installer';
 
@@ -34,13 +32,11 @@ use base 'Kwiki::SOAP::Wafl';
 
 sub html {
     my ($type) = split(' ', $self->arguments);
-    $self->use_class('fortunesoap');
-    my $result = $self->fortunesoap->get_result($type);
-
+    my $result = $self->hub->fortunesoap->get_result($type);
 
     $self->hub->template->process('fortune_soap.html',
         fortune => $result,
-        soap_class  => $self->fortunesoap->class_id,
+        soap_class  => $self->hub->fortunesoap->class_id,
     );
 }
 
